#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `sanskritwordnet` package."""

import unittest
from sanskritwordnet import SanskritWordNet


class TestIndex(unittest.TestCase):
    """Tests for `sanskritwordnet` package."""

    def setUp(self):
        """Set up test fixtures, if any."""

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_lemmas(self):
        """Test the Sanskrit WordNet API (synsets)."""

        LWN = SanskritWordNet()
        assert LWN.synsets(pos='n', offset='04349777').get()[0]['gloss'].startswith(
            'possession of the qualities'
        )
        assert LWN.synsets(pos='n', offset='04349777').lemmas
        assert '!' in LWN.synsets(pos='n', offset='04349777').relations
        assert len(LWN.synsets(pos='p').get()) > 3
        assert LWN.synsets(pos='n', offset='04349777').sentiment['objectivity'] == 0.75
        assert LWN.synsets(gloss='warfare').search()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `sanskritwordnet` package."""

import unittest
from sanskritwordnet import SanskritWordNet


class TestIndex(unittest.TestCase):
    """Tests for `sanskritwordnet` package."""

    def setUp(self):
        """Set up test fixtures, if any."""

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_lemmas(self):
        """Test the Sanskrit WordNet API (sentiment analysis)."""

        # Requires authentication
        # LWN = SanskritWordNet(token='')
        # assert LWN.sentiment_analysis('odiosus es mihi').json() == [
        #     [
        #         [
        #             {
        #                 'lemma': 'odiosus', 'morpho': 'aps---mn1-', 'uri': 'o0512'
        #             },
        #             {
        #                 'lemma': 'sum', 'morpho': 'v1spia--3-', 'uri': 's3436'
        #             }
        #         ],
        #         -0.207
        #     ]
        # ]




#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `sanskritwordnet` package."""


import unittest
from sanskritwordnet import SanskritWordNet


class TestIndex(unittest.TestCase):
    """Tests for `sanskritwordnet` package."""

    def setUp(self):
        """Set up test fixtures, if any."""

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_index(self):
        """Test the Sanskrit WordNet API (index)."""

        LWN = SanskritWordNet()
        assert next(LWN.index())['lemma'] == 'Aaron'
        assert next(LWN.index(pos='v'))['lemma'] == 'abaestumo'
        assert next(LWN.index(morpho='aps---mn1-'))['lemma'] == 'abacinus'





#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `sanskritwordnet` package."""

import unittest
from sanskritwordnet import SanskritWordNet


class TestIndex(unittest.TestCase):
    """Tests for `sanskritwordnet` package."""

    def setUp(self):
        """Set up test fixtures, if any."""

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_lemmas(self):
        """Test the Sanskrit WordNet API (lemmas)."""

        LWN = SanskritWordNet()
        assert LWN.lemmas(lemma='uirtus').get()[0]['uri'] == 'u0800'
        assert LWN.lemmas_by_uri('u0800').get()[0]['lemma'] == 'uirtus'
        assert next(LWN.lemmas(lemma='bula').search())['lemma'] == 'adfabulatio'
        assert LWN.lemmas(lemma='uirtus').synsets
        assert LWN.lemmas(lemma='uirtus').relations
